@@ -25,16 +25,16 @@
 #include <akonadi/itemserializerplugin.h>
 #include <kabc/vcardconverter.h>
 
-namespace AkonadiFuture {
+namespace Akonadi {
 
-class SerializerPluginAddressee : public QObject, public Akonadi::ItemSerializerPlugin
+class SerializerPluginAddressee : public QObject, public ItemSerializerPlugin
 {
     Q_OBJECT
     Q_INTERFACES( Akonadi::ItemSerializerPlugin )
 
 public:
-    bool deserialize( Akonadi::Item& item, const QByteArray& label, QIODevice& data, int version );
-    void serialize( const Akonadi::Item& item, const QByteArray& label, QIODevice& data, int &version );
+    bool deserialize( Item& item, const QByteArray& label, QIODevice& data, int version );
+    void serialize( const Item& item, const QByteArray& label, QIODevice& data, int &version );
 private:
     KABC::VCardConverter m_converter;
 };
