@@ -30,13 +30,11 @@
 #include <akonadi/private/imapparser_p.h>
 
 using namespace Akonadi;
-using namespace AkonadiFuture;
 using namespace KMime;
 
-typedef boost::shared_ptr<KMime::Message> MessagePtr;
-
 template <typename T> static void parseAddrList( const QList<QByteArray> &addrList, T *hdr )
 {
+  hdr->clear();
   for ( QList<QByteArray>::ConstIterator it = addrList.constBegin(); it != addrList.constEnd(); ++it ) {
     QList<QByteArray> addr;
     ImapParser::parseParenthesizedList( *it, addr );
@@ -59,13 +57,13 @@ bool SerializerPluginMail::deserialize( Item& item, const QByteArray& label, QIO
     if ( label != MessagePart::Body && label != MessagePart::Envelope && label != MessagePart::Header )
       return false;
 
-    MessagePtr msg;
+    KMime::Message::Ptr msg;
     if ( !item.hasPayload() ) {
         Message *m = new  Message();
-        msg = MessagePtr( m );
+        msg = KMime::Message::Ptr( m );
         item.setPayload( msg );
     } else {
-        msg = item.payload<MessagePtr>();
+        msg = item.payload<KMime::Message::Ptr>();
     }
 
     QByteArray buffer = data.readAll();
@@ -181,9 +179,9 @@ void SerializerPluginMail::serialize( const Item& item, const QByteArray& label,
 
 QSet<QByteArray> SerializerPluginMail::parts(const Item & item) const
 {
-  if ( !item.hasPayload<MessagePtr>() )
+  if ( !item.hasPayload<KMime::Message::Ptr>() )
     return QSet<QByteArray>();
-  MessagePtr msg = item.payload<MessagePtr>();
+  KMime::Message::Ptr msg = item.payload<KMime::Message::Ptr>();
   QSet<QByteArray> set;
   // FIXME: we actually want "has any header" here, but the kmime api doesn't offer that yet
   if ( msg->hasContent() || msg->hasHeader( "Message-ID" ) ) {
@@ -194,6 +192,6 @@ QSet<QByteArray> SerializerPluginMail::parts(const Item & item) const
   return set;
 }
 
-Q_EXPORT_PLUGIN2( akonadi_serializer_mail, AkonadiFuture::SerializerPluginMail )
+Q_EXPORT_PLUGIN2( akonadi_serializer_mail, SerializerPluginMail )
 
 #include "akonadi_serializer_mail.moc"
