@@ -28,16 +28,12 @@ namespace KCal {
   class CalendarLocal;
 }
 
-class ICalResourceBase : public AkonadiFuture::SingleFileResource<Settings>
+class ICalResourceBase : public Akonadi::SingleFileResource<Settings>
 {
   Q_OBJECT
 
   public:
-    /**
-     * @param fileTypeDescription filter descriptor for the calendar file type,
-     *                            to display for the '*.ics *.ical' filter.
-     */
-    ICalResourceBase( const QString &id, const QString &fileTypeDescription );
+    ICalResourceBase( const QString &id );
     ~ICalResourceBase();
 
   public Q_SLOTS:
@@ -86,7 +82,6 @@ class ICalResourceBase : public AkonadiFuture::SingleFileResource<Settings>
 
   private:
     KCal::CalendarLocal *mCalendar;
-    const QString mFileDescription;
 };
 
 template <typename PayloadPtr>
@@ -98,9 +93,9 @@ bool ICalResourceBase::checkItemAddedChanged( const Akonadi::Item &item, CheckTy
   }
   if ( !item.hasPayload<PayloadPtr>() ) {
     QString msg = (type == CheckForAdded)
-	                  ? i18n("Unable to retrieve added item %1.", item.id() )
+                          ? i18n("Unable to retrieve added item %1.", item.id() )
                           : i18n("Unable to retrieve modified item %1.", item.id() );
-    cancelTask( msg.arg( item.id() ) );
+    cancelTask( msg );
     return false;
   }
   return true;
