@@ -21,6 +21,8 @@
 #include "settings.h"
 #include "settingsadaptor.h"
 
+#include "imapaccount.h"
+
 #include <kwallet.h>
 using KWallet::Wallet;
 
@@ -52,6 +54,41 @@ Settings *Settings::self()
     return s_globalSettings->q;
 }
 
+/**
+ * Maps the enum used to represent authentication in MailTransport (kdepimlibs)
+ * to the one used by the imap resource.
+ * @param authType the MailTransport auth enum value
+ * @return the corresponding KIMAP auth value.
+ * @note will cause fatal error if there is no mapping, so be careful not to pass invalid auth options (e.g., APOP) to this function.
+ */
+KIMAP::LoginJob::AuthenticationMode Settings::mapTransportAuthToKimap( MailTransport::Transport::EnumAuthenticationType::type authType )
+{
+  // typedef these for readability
+  typedef MailTransport::Transport::EnumAuthenticationType MTAuth;
+  typedef KIMAP::LoginJob KIAuth;
+  switch ( authType ) {
+    case MTAuth::ANONYMOUS:
+      return KIAuth::Anonymous;
+    case MTAuth::PLAIN:
+      return KIAuth::Plain;
+    case MTAuth::NTLM:
+      return KIAuth::NTLM;
+    case MTAuth::LOGIN:
+      return KIAuth::Login;
+    case MTAuth::GSSAPI:
+      return KIAuth::GSSAPI;
+    case MTAuth::DIGEST_MD5:
+      return KIAuth::DigestMD5;
+    case MTAuth::CRAM_MD5:
+      return KIAuth::CramMD5;
+    case MTAuth::CLEAR:
+      return KIAuth::ClearText;
+    default:
+      kFatal() << "mapping from Transport::EnumAuthenticationType ->  KIMAP::LoginJob::AuthenticationMode not possible";
+  }
+  return KIAuth::ClearText; // dummy value, shouldn't get here.
+}
+
 Settings::Settings( WId winId ) : SettingsBase(), m_winId( winId )
 {
     Q_ASSERT( !s_globalSettings->q );
@@ -68,7 +105,8 @@ void Settings::setWinId( WId winId )
 
 void Settings::requestPassword()
 {
-  if ( !m_password.isEmpty() ) {
+  if ( !m_password.isEmpty() ||
+       ( mapTransportAuthToKimap( (MailTransport::TransportBase::EnumAuthenticationType::type)authentication() ) == KIMAP::LoginJob::GSSAPI ) ) {
     emit passwordRequestCompleted( m_password, false );
   } else {
     Wallet *wallet = Wallet::openWallet( Wallet::NetworkWallet(), m_winId, Wallet::Asynchronous );
@@ -83,11 +121,17 @@ void Settings::onWalletOpened( bool success )
     emit passwordRequestCompleted( QString(), true );
   } else {
     Wallet *wallet = qobject_cast<Wallet*>( sender() );
+    bool passwordNotStoredInWallet = true;
     if ( wallet && wallet->hasFolder( "imap" ) ) {
         wallet->setFolder( "imap" );
         wallet->readPassword( config()->name(), m_password );
+      passwordNotStoredInWallet = false;
     }
-    emit passwordRequestCompleted( m_password, false );
+    if ( passwordNotStoredInWallet || m_password.isEmpty() )
+      requestManualAuth();
+    else
+      emit passwordRequestCompleted( m_password, passwordNotStoredInWallet );
+
     wallet->deleteLater();
   }
 }
@@ -118,12 +162,17 @@ QString Settings::password(bool *userRejected) const
       *userRejected = false;
     }
 
-    if ( !m_password.isEmpty() )
+    if ( !m_password.isEmpty() ||
+         ( mapTransportAuthToKimap( (MailTransport::TransportBase::EnumAuthenticationType::type)authentication() ) == KIMAP::LoginJob::GSSAPI ) )
       return m_password;
     Wallet* wallet = Wallet::openWallet( Wallet::NetworkWallet(), m_winId );
-    if ( wallet && wallet->isOpen() && wallet->hasFolder( "imap" ) ) {
+    if ( wallet && wallet->isOpen() ) {
+      if ( wallet->hasFolder( "imap" ) ) {
         wallet->setFolder( "imap" );
         wallet->readPassword( config()->name(), m_password );
+      } else {
+        wallet->createFolder( "imap" );
+      }
     } else if ( userRejected != 0 ) {
         *userRejected = true;
     }
@@ -131,21 +180,14 @@ QString Settings::password(bool *userRejected) const
     return m_password;
 }
 
-bool Settings::passwordPossible() const
-{
-    bool possible = true;
-    Wallet* wallet = Wallet::openWallet( Wallet::NetworkWallet(), m_winId );
-    if ( !wallet ) {
-        possible = false;
-    }
-    delete wallet;
-    return possible;
-}
-
 void Settings::setPassword( const QString & password )
 {
     if ( password == m_password )
         return;
+
+    if ( mapTransportAuthToKimap( (MailTransport::TransportBase::EnumAuthenticationType::type)authentication() ) == KIMAP::LoginJob::GSSAPI )
+        return;
+
     m_password = password;
     Wallet* wallet = Wallet::openWallet( Wallet::NetworkWallet(), m_winId );
     if ( wallet && wallet->isOpen() ) {
@@ -155,6 +197,34 @@ void Settings::setPassword( const QString & password )
         wallet->writePassword( config()->name(), password );
         kDebug() << "Wallet save: " << wallet->sync() << endl;
     }
+    delete wallet;
+}
+
+void Settings::loadAccount( ImapAccount *account ) const
+{
+  account->setServer( imapServer() );
+  if ( imapPort()>=0 ) {
+    account->setPort( imapPort() );
+  }
+
+  account->setUserName( userName() );
+  account->setSubscriptionEnabled( subscriptionEnabled() );
+
+  QString encryption = safety();
+  if ( encryption == "SSL" ) {
+    account->setEncryptionMode( KIMAP::LoginJob::AnySslVersion );
+  } else if (  encryption == "STARTTLS" ) {
+    account->setEncryptionMode( KIMAP::LoginJob::TlsV1 );
+  } else {
+    account->setEncryptionMode( KIMAP::LoginJob::Unencrypted );
+  }
+
+  account->setAuthenticationMode(
+      mapTransportAuthToKimap(
+          (MailTransport::TransportBase::EnumAuthenticationType::type) authentication()
+      )
+  );
+
 }
 
 #include "settings.moc"
