@@ -46,8 +46,7 @@ using namespace Kolab;
 
 
 Incidence::Incidence( const QString& tz, KCal::Incidence* incidence )
-  : KolabBase( tz ), mFloatingStatus( Unset ), mHasAlarm( false ),
-    mRevision( 0 )
+  : KolabBase( tz ), mFloatingStatus( Unset ), mHasAlarm( false )
 {
 }
 
@@ -157,16 +156,6 @@ QString Incidence::internalUID() const
   return mInternalUID;
 }
 
-void Incidence::setRevision( int revision )
-{
-  mRevision = revision;
-}
-
-int Incidence::revision() const
-{
-  return mRevision;
-}
-
 bool Incidence::loadAttendeeAttribute( QDomElement& element,
                                        Attendee& attendee )
 {
@@ -340,9 +329,14 @@ void Incidence::loadRecurrence( const QDomElement& element )
     if ( n.isElement() ) {
       QDomElement e = n.toElement();
       QString tagName = e.tagName();
-
-      if ( tagName == "interval" )
-        mRecurrence.interval = e.text().toInt();
+      if ( tagName == "interval" ) {
+        //kolab/issue4229, sometimes  the interval value can be empty
+        if ( e.text().isEmpty() || e.text().toInt() <= 0 ) {
+          mRecurrence.interval = 1;
+        } else {
+          mRecurrence.interval = e.text().toInt();
+        }
+      }
       else if ( tagName == "day" ) // can be present multiple times
         mRecurrence.days.append( e.text() );
       else if ( tagName == "daynumber" )
@@ -508,12 +502,7 @@ bool Incidence::loadAttribute( QDomElement& element )
     loadAlarms( element );
   else if ( tagName == "x-kde-internaluid" )
     setInternalUID( element.text() );
-  else if ( tagName == "revision" ) {
-    bool ok;
-    int revision = element.text().toInt( &ok );
-    if ( ok )
-      setRevision( revision );
-  } else if ( tagName == "x-custom" ) {
+  else if ( tagName == "x-custom" ) {
     loadCustomAttributes( element );
   } else if ( tagName == "inline-attachment"  ) {
     // we handle that separately later on, so no need to create a KolabUnhandled entry for it
@@ -555,7 +544,6 @@ bool Incidence::saveAttributes( QDomElement& element ) const
   }
   saveAlarms( element );
   writeString( element, "x-kde-internaluid", internalUID() );
-  writeString( element, "revision", QString::number( revision() ) );
   saveCustomAttributes( element );
   return true;
 }
